@@ -1,4 +1,4 @@
 from .fields import AppDataField, ListModelMultipleChoiceField
-from .registry import app_registry
+from .registry import app_registry, NamespaceRegistry
 from .containers import AppDataContainer
 from .forms import AppDataForm, multiform_factory, MultiForm
