@@ -15,12 +15,15 @@ try:
 except ImportError:
     import pickle
 
+
 class DummyAppDataContainer(AppDataContainer):
     pass
 
+
 class DummyAppDataContainer2(AppDataContainer):
     pass
 
+
 class TestForms(AppDataTestCase):
     def test_container_from_form(self):
         class MyForm(AppDataForm):
@@ -93,6 +96,13 @@ class TestSerialization(AppDataTestCase):
         unpickled_article = pickle.loads(data)
         self._test_article(unpickled_article)
 
+    def test_pickle_supports_containers(self):
+        self.article.app_data.myapp
+        data = pickle.dumps(self.article)
+        unpickled_article = pickle.loads(data)
+        self._test_article(unpickled_article)
+
+
 class TestAppDataContainers(AppDataTestCase):
     def test_registered_classes_can_behave_as_attrs(self):
         app_registry.register('dummy', DummyAppDataContainer)
@@ -151,8 +161,8 @@ class TestAppDataContainers(AppDataTestCase):
         data = inst.app_data.get('dummy', {})
         data['foo'] = 'bar'
         tools.assert_equals(data['foo'], 'bar')
-        tools.assert_equals(data.keys(), ['foo'])
-        tools.assert_equals(data.values(), ['bar'])
+        tools.assert_equals(list(data.keys()), ['foo'])
+        tools.assert_equals(list(data.values()), ['bar'])
 
     def test_alternate_registry(self):
         def _get_namespace(instance, namespace):
